@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,6 +13,7 @@
 #include <KFontSizeAction>
 #include <KLocalizedString>
 #include <KToggleAction>
+#include <QActionGroup>
 #include <QTextCharFormat>
 #include <QTextList>
 
@@ -21,8 +22,8 @@ using namespace KPIMTextEdit;
 class Q_DECL_HIDDEN RichTextComposerActions::RichTextComposerActionsPrivate
 {
 public:
-    RichTextComposerActionsPrivate(KPIMTextEdit::RichTextComposerControler *controler)
-        : composerControler(controler)
+    RichTextComposerActionsPrivate(KPIMTextEdit::RichTextComposerControler *controller)
+        : composerControler(controller)
     {
     }
 
@@ -77,9 +78,9 @@ public:
     bool richTextEnabled = false;
 };
 
-RichTextComposerActions::RichTextComposerActions(KPIMTextEdit::RichTextComposerControler *controler, QObject *parent)
+RichTextComposerActions::RichTextComposerActions(KPIMTextEdit::RichTextComposerControler *controller, QObject *parent)
     : QObject(parent)
-    , d(new RichTextComposerActions::RichTextComposerActionsPrivate(controler))
+    , d(new RichTextComposerActions::RichTextComposerActionsPrivate(controller))
 {
 }
 
